@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2022 Greg Albrecht <oss@undef.net>
+# Copyright 2023 Greg Albrecht <oss@undef.net>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,32 +13,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# Author:: Greg Albrecht W2GMD <oss@undef.net>
-#
 
-"""SpotCOT Gateway Functions."""
+"""INRCOT Gateway Functions."""
 
 import datetime
 import io
 import xml.etree.ElementTree as ET
 
 from configparser import ConfigParser
-from typing import Union, Set
+from typing import Optional, Set
+
+from aiohttp import BasicAuth
 
 import pytak
 import inrcot
 
 
-__author__ = "Greg Albrecht W2GMD <oss@undef.net>"
-__copyright__ = "Copyright 2022 Greg Albrecht"
+__author__ = "Greg Albrecht <oss@undef.net>"
+__copyright__ = "Copyright 2023 Greg Albrecht"
 __license__ = "Apache License, Version 2.0"
 
 
 def create_tasks(
     config: ConfigParser, clitool: pytak.CLITool, original_config: ConfigParser
 ) -> Set[pytak.Worker,]:
-    """
-    Creates specific coroutine task set for this application.
+    """Create specific coroutine task set for this application.
 
     Parameters
     ----------
@@ -55,18 +54,52 @@ def create_tasks(
     return set([inrcot.Worker(clitool.tx_queue, config, original_config)])
 
 
-def split_feed(content: str) -> list:
-    """Splits an inReach MapShare KML feed by 'Folder'"""
+def split_feed(content: bytes) -> Optional[list]:
+    """Split an inReach MapShare KML feed by 'Folder'."""
     tree = ET.parse(io.BytesIO(content))
     document = tree.find("{http://www.opengis.net/kml/2.2}Document")
+    if not document:
+        return None
     folder = document.findall("{http://www.opengis.net/kml/2.2}Folder")
     return folder
 
 
-def inreach_to_cot_xml(feed: str, feed_conf: dict = None) -> Union[ET.Element, None]:
-    """
-    Converts an inReach Response to a Cursor-on-Target Event, as an XML Obj.
-    """
+def make_feed_conf(section) -> dict:
+    """Make a feed conf dictionary from a conf."""
+    feed_conf: dict = {
+        "feed_url": section.get("FEED_URL"),
+        "cot_stale": section.get("COT_STALE", inrcot.DEFAULT_COT_STALE),
+        "cot_type": section.get("COT_TYPE", inrcot.DEFAULT_COT_TYPE),
+        "cot_icon": section.get("COT_ICON"),
+        "cot_name": section.get("COT_NAME"),
+    }
+    # Support "private" MapShare feeds:
+    feed_pass: str = section.get("FEED_PASSWORD")
+    feed_user: str = section.get("FEED_USERNAME")
+    if feed_pass and feed_user:
+        feed_auth: BasicAuth = BasicAuth(feed_user, feed_pass)
+        feed_conf["feed_auth"] = str(feed_auth)
+
+    return feed_conf
+
+
+def create_feeds(config: ConfigParser) -> list:
+    """Create a list of feed configurations."""
+    feeds: list = []
+    for feed in config.sections():
+        if not "inrcot_feed_" in feed:
+            continue
+        config_section = config[feed]
+        feed_conf: dict = make_feed_conf(config_section)
+        feed_conf["feed_name"] = feed
+        feeds.append(feed_conf)
+    return feeds
+
+
+def inreach_to_cot_xml(
+    feed: str, feed_conf: Optional[dict] = None
+) -> Optional[ET.Element]:
+    """Convert an inReach Response to a Cursor-on-Target Event, as an XML Obj."""
     feed_conf = feed_conf or {}
 
     placemarks = feed.find("{http://www.opengis.net/kml/2.2}Placemark")
@@ -77,8 +110,11 @@ def inreach_to_cot_xml(feed: str, feed_conf: dict = None) -> Union[ET.Element, N
     ts = placemarks.find("{http://www.opengis.net/kml/2.2}TimeStamp")
     when = ts.find("{http://www.opengis.net/kml/2.2}when").text
 
+    if not "," in coordinates or coordinates.count(",") != 2:
+        return None
+
     lon, lat, alt = coordinates.split(",")
-    if lat is None or lon is None:
+    if not all([lat, lon]):
         return None
 
     time = when
@@ -103,20 +139,11 @@ def inreach_to_cot_xml(feed: str, feed_conf: dict = None) -> Union[ET.Element, N
     point.set("ce", "9999999.0")
     point.set("le", "9999999.0")
 
-    uid = ET.Element("UID")
-    uid.set("Droid", f"{name} (inReach)")
-
     contact = ET.Element("contact")
     contact.set("callsign", f"{callsign} (inReach)")
 
-    track = ET.Element("track")
-    track.set("course", "9999999.0")
-
     detail = ET.Element("detail")
-    detail.set("uid", name)
-    detail.append(uid)
     detail.append(contact)
-    detail.append(track)
 
     remarks = ET.Element("remarks")
 
@@ -126,6 +153,12 @@ def inreach_to_cot_xml(feed: str, feed_conf: dict = None) -> Union[ET.Element, N
     remarks.text = _remarks
     detail.append(remarks)
 
+    cot_icon: Optional[str] = feed_conf.get("cot_icon")
+    if cot_icon:
+        usericon = ET.Element("usericon")
+        usericon.set("iconsetpath", cot_icon)
+        detail.append(usericon)
+
     root = ET.Element("event")
     root.set("version", "2.0")
     root.set("type", cot_type)
@@ -140,7 +173,7 @@ def inreach_to_cot_xml(feed: str, feed_conf: dict = None) -> Union[ET.Element, N
     return root
 
 
-def inreach_to_cot(content: str, feed_conf: dict = None) -> Union[bytes, None]:
-    """Wrapper that returns COT as an XML string."""
-    cot: Union[ET.Element, None] = inreach_to_cot_xml(content, feed_conf)
+def inreach_to_cot(content: str, feed_conf: Optional[dict] = None) -> Optional[bytes]:
+    """Render a CoT XML as a string."""
+    cot: Optional[ET.Element] = inreach_to_cot_xml(content, feed_conf)
     return ET.tostring(cot) if cot else None
